function gameplay_load()
	mousex=love.mouse.getX() --variables for tracking mouse movement
	mousey=love.mouse.getY()
	mousex_previous=love.mouse.getX()
	mousey_previous=love.mouse.getY()
	
	world:setAllowSleep(false)
	world:setCallbacks(collision_new,collision_persist,collision_end,collision_result)

	gameplay_paused=0 --pause menu stuff
	pausemenu_alpha=0
end

function gameplay_update()
	mousex_previous=mousex --track mouse movement
	mousey_previous=mousey
	mousex=love.mouse.getX() 
	mousey=love.mouse.getY()

	local a
	for a=1,objectnum-1 do
		if object[a].kind=="platform" then
			if platform_active[a]==1 and love.mouse.isDown("l") then --rotate platforms
				platform[a]:setAngularVelocity((math.rad(((mousex-mousex_previous)+(mousey-mousey_previous))/4))/love.timer.getDelta())
			else
				platform[a]:setAngularVelocity(0)
			end
			
			if platform[a]:getAngularVelocity()>math.rad(300) then --limit platform rotation speed
				platform[a]:setAngularVelocity(math.rad(300))
			elseif platform[a]:getAngularVelocity()<math.rad(-300) then
				platform[a]:setAngularVelocity(math.rad(-300))
			end

			platform[a]:setX(object[a].x) --keep ball from pushing platforms
			platform[a]:setY(object[a].y)
		end
	end
	
	local x,y=ball:getLinearVelocity() --limit ball speed
	if x>400 then ball:setLinearVelocity(400,y) end
	if x<-400 then ball:setLinearVelocity(-400,y) end
	if y>500 then ball:setLinearVelocity(x,500) end
	if y<-500 then ball:setLinearVelocity(x,-500) end
	
	if ball:getY()>love.graphics.getHeight() then --check if ball falls of bottom of screen
		createlevel()
		gameplay_load()
	end
	
	if ball:getX()<0 then --check if ball goes past left edge of screen
		createlevel()
		gameplay_load()
	end
	
	if ball:getX()>love.graphics.getWidth() then --same for right edge
		createlevel()
		gameplay_load()
	end
	
	if gameplay_paused==0 then
		world:update(love.timer.getDelta())
	end

	if gameplay_paused==1 then --pause menu stuff
		pausemenu_alpha=pausemenu_alpha+8*love.timer.getDelta()

		if love.mouse.getY()>450 then pausemenu_selected=3
		elseif love.mouse.getY()>375 then pausemenu_selected=2
		else pausemenu_selected=1 end
	else
		pausemenu_alpha=pausemenu_alpha-8*love.timer.getDelta()
	end

	if pausemenu_alpha>.85 then pausemenu_alpha=.85 end
	if pausemenu_alpha<0 then pausemenu_alpha=0 end
end

function collision_new(first,second,contact)
	if first=="goal" and second=="ball" then --check if ball meets goal
		createlevel()
		gameplay_load()
	end
	
	if first=="ball" and second=="spike" then --check if ball hits spikes
		createlevel()
		gameplay_load()
	end
	
	local a, b --activate platforms when ball touches them
	for a=1,objectnum-1 do
		if first=="platform"..tostring(a) and second=="ball" then
			for b=1,objectnum-1 do
				platform_active[b]=0
			end
			platform_active[a]=1
		end
	end
end

function gameplay_draw()
	--draw physics stuff
	local a, b
	for a=1,objectnum-1 do
		if object[a].kind=="ball" then --draw ball
			love.graphics.setColor(255,255,255,255)
			love.graphics.circle("fill",ball:getX(),ball:getY(),ball_shape:getRadius(),16)
		end
		
		if object[a].kind=="goal" then --draw goal
			love.graphics.setColor(0,255,0,255)
			love.graphics.rectangle("fill",goal:getX()-16,goal:getY()-16,32,32)
		end
		
		if object[a].kind=="wall" then --draw wall
			love.graphics.setColor(128,128,128,255)
			love.graphics.rectangle("fill",wall[a]:getX()-16,wall[a]:getY()-16,30,30)
		end
		
		if object[a].kind=="spike" then --draw spikeballs
			love.graphics.setColor(255,255,255,255)
			love.graphics.draw(image_spikeball,spike[a]:getX()-15,spike[a]:getY()-15)
		end
		
		if object[a].kind=="platform" then --draw platform shapes
			if platform_active[a]==1 then
				love.graphics.setColor(255,0,0,255)
			else
				love.graphics.setColor(255,255,255,255)
			end
			
			for b=1,shape_amount[a] do
				love.graphics.polygon("fill",platform_shape[a][b]:getPoints())
			end
		end
	end

	--draw pause menu
	love.graphics.setColor(0,0,0,255*pausemenu_alpha)
	love.graphics.rectangle("fill",0,0,love.graphics.getWidth(),love.graphics.getHeight())
	love.graphics.setFont(font_verasans20)
	love.graphics.setColor(255,255,255,255*pausemenu_alpha)
	love.graphics.printf("Paused",50,150,love.graphics.getWidth()-100,"center")

	love.graphics.setLineWidth(4)

	if pausemenu_selected==1 then --draw button backgrounds
		love.graphics.setColor(128,128,128,150*pausemenu_alpha)
	else
		love.graphics.setColor(128,128,128,100*pausemenu_alpha)
	end
	love.graphics.rectangle("fill",love.graphics.getWidth()/2-100,300,200,50)

	if pausemenu_selected==2 then
		love.graphics.setColor(128,128,128,150*pausemenu_alpha)
	else
		love.graphics.setColor(128,128,128,100*pausemenu_alpha)
	end
	love.graphics.rectangle("fill",love.graphics.getWidth()/2-100,375,200,50)

	if pausemenu_selected==3 then
		love.graphics.setColor(128,128,128,150*pausemenu_alpha)
	else
		love.graphics.setColor(128,128,128,100*pausemenu_alpha)
	end
	love.graphics.rectangle("fill",love.graphics.getWidth()/2-100,450,200,50)

	if pausemenu_selected==1 then --draw buttons
		love.graphics.setColor(255,255,255,255*pausemenu_alpha)
	else
		love.graphics.setColor(200,200,200,255*pausemenu_alpha)
	end
	love.graphics.rectangle("line",love.graphics.getWidth()/2-100,300,200,50)
	love.graphics.printf("Continue",love.graphics.getWidth()/2-80,325,160,"center")

	if pausemenu_selected==2 then
		love.graphics.setColor(255,255,255,255*pausemenu_alpha)
	else
		love.graphics.setColor(200,200,200,255*pausemenu_alpha)
	end
	love.graphics.rectangle("line",love.graphics.getWidth()/2-100,375,200,50)
	love.graphics.printf("Restart level",love.graphics.getWidth()/2-80,400,160,"center")

	if pausemenu_selected==3 then
		love.graphics.setColor(255,255,255,255*pausemenu_alpha)
	else
		love.graphics.setColor(200,200,200,255*pausemenu_alpha)
	end
	love.graphics.rectangle("line",love.graphics.getWidth()/2-100,450,200,50)
	love.graphics.printf("Quit to menu",love.graphics.getWidth()/2-80,475,160,"center")
end
